@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Play the tabla!
 
-our $VERSION = '0.0703';
+our $VERSION = '0.0704';
 
 use Moo;
 use File::ShareDir qw(dist_dir);
@@ -33,8 +33,7 @@ has patches => (
     default => sub {
         {
             # single strikes
-            ga   => [qw(65)],
-            ge   => [qw(66 76)],
+            ge   => [qw(65 66 76)],
             ke   => [qw(64 77 79)],
             na   => [qw(78 81)],
             ta   => [qw(71 75 85)],
@@ -234,7 +233,7 @@ Music::Percussion::Tabla - Play the tabla!
 
 =head1 VERSION
 
-version 0.0703
+version 0.0704
 
 =head1 SYNOPSIS
 
@@ -347,8 +346,7 @@ Each bol can be 1 or more patch numbers.
 
 Default single strike bol patches:
 
-  ga:   65
-  ge:   66 76
+  ge:   65 66 76
   ke:   64 77 79
   na:   78 81
   ta:   71 75 85
@@ -397,7 +395,7 @@ above.)
 
 1. Single strike bols:
 
-  ga, ge, ke, na, ta, ti, tin, tun
+  ge, ke, na, ta, ti, tin, tun
 
 2. Double strike bols:
 
